@@ -29,7 +29,7 @@ class SSHResponse:
         return json.dumps(dict_, indent=4)
 
     @property
-    def stdout(self) -> None | str | dict:
+    def stdout(self) -> None | str | dict | list:
         out = self.__out
         try:
             out = json.loads(out)
@@ -1402,15 +1402,19 @@ class Plinux:
 
         cmd = 'grep "NTP" /etc/systemd/timesyncd.conf | grep -v "#"'
         response = self.run_cmd(cmd).stdout
+        values = re.findall(r'NTP=(.+)', response)  # ['172.16.0.3 ntp.com'] or ['172.16.0.3', '172.16.0.4']
+
+        if len(values) > 1:
+            # NTP=172.16.0.3
+            # FallbackNTP=172.16.0.4
+            return values
+
+        # For NTP=172.16.0.3 ntp.com
         try:
-            result_lines = response.splitlines()
-        except AttributeError:
+            return values[0].split()
+        except IndexError:
             return []
 
-        result = [ntp.split('=')[-1] for ntp in result_lines]
-
-        return result
-
     # Aliases
     cat = cat_file
     ps = get_processes
